==> xiaoerke-common-1.0.25-sources.jar: com/cxqm/xiaoerke/modules/sys/entity/Invite.java <==
package com.cxqm.xiaoerke.modules.sys.entity;

/**
 * Created by sunzb on 2017/10/30.
 */
public class Invite {

    private String id;
    private String path;
    private String down;
    private String type;
    private String name;

    private String qrPath;
    private String qrDown;
    private String qrType;
    private String qrName;

    private String x;
    private String y;
    private String w;
    private String h;

    private String qrx;
    private String qry;
    private String qrw;
    private String qrh;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getPath() {
        return path;
    }

    public void setPath(String path) {
        this.path = path;
    }

    public String getDown() {
        return down;
    }

    public void setDown(String down) {
        this.down = down;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getX() {
        return x;
    }

    public void setX(String x) {
        this.x = x;
    }

    public String getY() {
        return y;
    }

    public void setY(String y) {
        this.y = y;
    }

    public String getW() {
        return w;
    }

    public void setW(String w) {
        this.w = w;
    }

    public String getH() {
        return h;
    }

    public void setH(String h) {
        this.h = h;
    }

    public String getQrPath() {
        return qrPath;
    }

    public void setQrPath(String qrPath) {
        this.qrPath = qrPath;
    }

    public String getQrDown() {
        return qrDown;
    }

    public void setQrDown(String qrDown) {
        this.qrDown = qrDown;
    }

    public String getQrType() {
        return qrType;
    }

    public void setQrType(String qrType) {
        this.qrType = qrType;
    }

    public String getQrName() {
        return qrName;
    }

    public void setQrName(String qrName) {
        this.qrName = qrName;
    }

    public String getQrx() {
        return qrx;
    }

    public void setQrx(String qrx) {
        this.qrx = qrx;
    }

    public String getQry() {
        return qry;
    }

    public void setQry(String qry) {
        this.qry = qry;
    }

    public String getQrw() {
        return qrw;
    }

    public void setQrw(String qrw) {
        this.qrw = qrw;
    }

    public String getQrh() {
        return qrh;
    }

    public void setQrh(String qrh) {
        this.qrh = qrh;
    }
}

==> xiaoerke-common-1.0.31-sources.jar: com/cxqm/xiaoerke/modules/sys/entity/Invite.java <==
package com.cxqm.xiaoerke.modules.sys.entity;

/**
 * Created by sunzb on 2017/10/30.
 */
public class Invite {

    private String id;
    private String path;
    private String down;
    private String type;
    private String name;

    private String qrPath;
    private String qrDown;
    private String qrType;
    private String qrName;

    private String shPath;
    private String shName;
    private String shType;

    private String x;
    private String y;
    private String w;
    private String h;

    private String qrx;
    private String qry;
    private String qrw;
    private String qrh;
    private String shw;
    private String shh;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getPath() {
        return path;
    }

    public void setPath(String path) {
        this.path = path;
    }

    public String getDown() {
        return down;
    }

    public void setDown(String down) {
        this.down = down;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getX() {
        return x;
    }

    public void setX(String x) {
        this.x = x;
    }

    public String getY() {
        return y;
    }

    public void setY(String y) {
        this.y = y;
    }

    public String getW() {
        return w;
    }

    public void setW(String w) {
        this.w = w;
    }

    public String getH() {
        return h;
    }

    public void setH(String h) {
        this.h = h;
    }

    public String getQrPath() {
        return qrPath;
    }

    public void setQrPath(String qrPath) {
        this.qrPath = qrPath;
    }

    public String getQrDown() {
        return qrDown;
    }

    public void setQrDown(String qrDown) {
        this.qrDown = qrDown;
    }

    public String getQrType() {
        return qrType;
    }

    public void setQrType(String qrType) {
        this.qrType = qrType;
    }

    public String getQrName() {
        return qrName;
    }

    public void setQrName(String qrName) {
        this.qrName = qrName;
    }

    public String getQrx() {
        return qrx;
    }

    public void setQrx(String qrx) {
        this.qrx = qrx;
    }

    public String getQry() {
        return qry;
    }

    public void setQry(String qry) {
        this.qry = qry;
    }

    public String getQrw() {
        return qrw;
    }

    public void setQrw(String qrw) {
        this.qrw = qrw;
    }

    public String getQrh() {
        return qrh;
    }

    public void setQrh(String qrh) {
        this.qrh = qrh;
    }

    public String getShPath() {
        return shPath;
    }

    public void setShPath(String shPath) {
        this.shPath = shPath;
    }

    public String getShName() {
        return shName;
    }

    public void setShName(String shName) {
        this.shName = shName;
    }

    public String getShType() {
        return shType;
    }

    public void setShType(String shType) {
        this.shType = shType;
    }

    public String getShw() {
        return shw;
    }

    public void setShw(String shw) {
        this.shw = shw;
    }

    public String getShh() {
        return shh;
    }

    public void setShh(String shh) {
        this.shh = shh;
    }
}
